CalCentralityScore: Calculating eigenvector centrality of subpathways
Description
The function "CalCentralityScore" is used to calculate the eigenvector centrality of subpathways.
Usage
CalCentralityScore(ExpData,Label,nperm=1000)
Value
A dataframe with seven columns those are subpathway ID, subpathway name, subpathway size, genes in subpathway, centralscore (eigenvector centrality), Pvalue and FDR.
Arguments
ExpData
A gene expression profile of interest (rows are genes, columns are samples).
Label
A character vector consist of "0" and "1" which represent sample class in gene expression profile. "0" means normal sample and "1" means disease sample.