#Load depend package
library(GSVA)
library(pheatmap)
##Obtain input data
#Statistic significance of centrality score of subpathways
#induced by each drug were stored in package "DRviaSPCNData".
#"DRviaSPCNData" has been uploaded to the github repository.
#Users can download and install through "install_github" function and
#set parameter url="hanjunwei-lab/DRviaSPCNData".
#After installing and loading package "DRviaSPCNData",
#users can use the following command to get the data:
#DrugSPPvalueMatrix<-GetData('DrugSPPvalueMatrix')
GEP<-GetExample('GEP')
Slabel<-GetExample('Slabel')
#Run the function
#Drug2SPheatmap(drugname = "methotrexate_HL60_6_8.8e-06",
# DrugSPPvalue=DrugSPPvalueMatrix,
# ExpData=GEP,Label=Slabel,pcut=0.05,bk=c(-2,2),
# cluster.rows=FALSE,cluster.cols=FALSE,show.rownames=TRUE,
# show.colnames=FALSE,col=c("navy","firebrick3"),
# cell.width=NA,cell.height=NA,scale="row",fontsize=7,
# fontsize.row=9,fontsize.col=10)
Run the code above in your browser using DataLab