##Obtain input data
#Weighted enrichmentscore of subpathways induced by each drug were stored
#in package "DRviaSPCNData". "DRviaSPCNData" has been uploaded to the
#github repository.Users can download and install through "install_github"
#function and set parameter url="hanjunwei-lab/DRviaSPCNData".
#After installing and loading package "DRviaSPCNData",
#users can use the following command to get the data.
#DrugSPESCMatrix<-GetData('DrugSPESCMatrix')
CentralityScoreResult<-GetExample("CentralityScoreResult")
GEP<-GetExample("GEP")
Slabel<-GetExample("Slabel")
#Run the function
#Opdrugresult<-Optimaldrugs(ExpData=GEP,Label=Slabel,DrugSPESC=DrugSPESCMatrix,
#CentralityScore=CentralityScoreResult,nperm=1000,topcut=10,pcut=0.01,weight=FALSE)
Run the code above in your browser using DataLab